@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::PodSpelling; # git description: v2.007001-2-g5fee936
+package Dist::Zilla::Plugin::Test::PodSpelling; # git description: v2.007002-6-g4ddf499
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Author tests for POD spelling
 # KEYWORDS: plugin test spelling words stopwords typos errors documentation
 
-our $VERSION = '2.007002';
+our $VERSION = '2.007003';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -34,14 +34,14 @@ has wordlist => (
 has spell_cmd => (
     is      => 'ro',
     isa     => 'Str',
-    default => '',                           # default to original
+    default => '',
 );
 
 has stopwords => (
     is      => 'ro',
     isa     => 'ArrayRef[Str]',
     traits  => [ 'Array' ],
-    default => sub { [] },                   # default to original
+    default => sub { [] },
     handles => {
         push_stopwords => 'push',
         uniq_stopwords => 'uniq',
@@ -53,7 +53,7 @@ has directories => (
     isa     => 'ArrayRef[Str]',
     traits  => [ 'Array' ],
     is      => 'ro',
-    default => sub { [] },                   # default to original
+    default => sub { [ qw(bin lib) ] },
     handles => {
         no_directories => 'is_empty',
         print_directories => [ join => ' ' ],
@@ -128,11 +128,11 @@ sub munge_files {
 sub munge_file {
     my ($self, $file) = @_;
 
-    my ($set_spell_cmd, $add_stopwords, $stopwords);
-    if ($self->spell_cmd) {
-        $set_spell_cmd = sprintf "set_spell_cmd('%s');", $self->spell_cmd;
-    }
+    my $set_spell_cmd = $self->spell_cmd
+        ? sprintf("set_spell_cmd('%s');", $self->spell_cmd)
+        : undef;
 
+    # TODO - move this into an attribute builder
     foreach my $holder ( split( /\s/xms, join( ' ',
             @{ $self->zilla->authors },
             $self->zilla->copyright_holder,
@@ -152,10 +152,9 @@ sub munge_file {
         }
     }
 
-    unless ( $self->no_stopwords ) {
-        $add_stopwords = 'add_stopwords(<DATA>);';
-        $stopwords = join "\n", '__DATA__', $self->uniq_stopwords;
-    }
+    my $stopwords = $self->no_stopwords
+        ? undef
+        : join("\n", '__DATA__', sort $self->uniq_stopwords);
 
     $file->content(
         $self->fill_in_string(
@@ -165,7 +164,6 @@ sub munge_file {
                 version       => __PACKAGE__->VERSION,
                 wordlist      => \$self->wordlist,
                 set_spell_cmd => \$set_spell_cmd,
-                add_stopwords => \$add_stopwords,
                 stopwords     => \$stopwords,
                 directories   => \$self->print_directories,
             }
@@ -276,7 +274,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.007002
+version 2.007003
 
 =head1 SYNOPSIS
 
@@ -437,6 +435,6 @@ use Test::Spelling 0.12;
 use {{ $wordlist }};
 
 {{ $set_spell_cmd }}
-{{ $add_stopwords }}
-all_pod_files_spelling_ok( qw( bin lib {{ $directories }} ) );
+{{ $stopwords ? 'add_stopwords(<DATA>);' : undef }}
+all_pod_files_spelling_ok( qw( {{ $directories }} ) );
 {{ $stopwords }}
